# coding: utf-8
import pprint
import six
from enum import Enum



class BankTransaction:

    swagger_types = {
    
        'adjustments': 'list[PaymentAdjustment]',
        'created_by': 'int',
        'created_on': 'datetime',
        'currency_bank_account': 'CurrencyBankAccount',
        'external_id': 'str',
        'flow_direction': 'BankTransactionFlowDirection',
        'id': 'int',
        'linked_space_id': 'int',
        'planned_purge_date': 'datetime',
        'posting_amount': 'float',
        'reference': 'str',
        'source': 'int',
        'state': 'BankTransactionState',
        'total_adjustment_amount_including_tax': 'float',
        'type': 'int',
        'value_amount': 'float',
        'value_date': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'adjustments': 'adjustments','created_by': 'createdBy','created_on': 'createdOn','currency_bank_account': 'currencyBankAccount','external_id': 'externalId','flow_direction': 'flowDirection','id': 'id','linked_space_id': 'linkedSpaceId','planned_purge_date': 'plannedPurgeDate','posting_amount': 'postingAmount','reference': 'reference','source': 'source','state': 'state','total_adjustment_amount_including_tax': 'totalAdjustmentAmountIncludingTax','type': 'type','value_amount': 'valueAmount','value_date': 'valueDate','version': 'version',
    }

    
    _adjustments = None
    _created_by = None
    _created_on = None
    _currency_bank_account = None
    _external_id = None
    _flow_direction = None
    _id = None
    _linked_space_id = None
    _planned_purge_date = None
    _posting_amount = None
    _reference = None
    _source = None
    _state = None
    _total_adjustment_amount_including_tax = None
    _type = None
    _value_amount = None
    _value_date = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.adjustments = kwargs.get('adjustments', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.currency_bank_account = kwargs.get('currency_bank_account', None)
        self.external_id = kwargs.get('external_id', None)
        self.flow_direction = kwargs.get('flow_direction', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.posting_amount = kwargs.get('posting_amount', None)
        self.reference = kwargs.get('reference', None)
        self.source = kwargs.get('source', None)
        self.state = kwargs.get('state', None)
        self.total_adjustment_amount_including_tax = kwargs.get('total_adjustment_amount_including_tax', None)
        self.type = kwargs.get('type', None)
        self.value_amount = kwargs.get('value_amount', None)
        self.value_date = kwargs.get('value_date', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def adjustments(self):
        """Gets the adjustments of this BankTransaction.

            The adjustments applied on this bank transaction.

        :return: The adjustments of this BankTransaction.
        :rtype: list[PaymentAdjustment]
        """
        return self._adjustments

    @adjustments.setter
    def adjustments(self, adjustments):
        """Sets the adjustments of this BankTransaction.

            The adjustments applied on this bank transaction.

        :param adjustments: The adjustments of this BankTransaction.
        :type: list[PaymentAdjustment]
        """

        self._adjustments = adjustments
    
    @property
    def created_by(self):
        """Gets the created_by of this BankTransaction.

            The created by indicates the user which has created the bank transaction.

        :return: The created_by of this BankTransaction.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BankTransaction.

            The created by indicates the user which has created the bank transaction.

        :param created_by: The created_by of this BankTransaction.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this BankTransaction.

            The date and time when the object was created.

        :return: The created_on of this BankTransaction.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this BankTransaction.

            The date and time when the object was created.

        :param created_on: The created_on of this BankTransaction.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def currency_bank_account(self):
        """Gets the currency_bank_account of this BankTransaction.

            The currency bank account which is used to handle money flow.

        :return: The currency_bank_account of this BankTransaction.
        :rtype: CurrencyBankAccount
        """
        return self._currency_bank_account

    @currency_bank_account.setter
    def currency_bank_account(self, currency_bank_account):
        """Sets the currency_bank_account of this BankTransaction.

            The currency bank account which is used to handle money flow.

        :param currency_bank_account: The currency_bank_account of this BankTransaction.
        :type: CurrencyBankAccount
        """

        self._currency_bank_account = currency_bank_account
    
    @property
    def external_id(self):
        """Gets the external_id of this BankTransaction.

            

        :return: The external_id of this BankTransaction.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this BankTransaction.

            

        :param external_id: The external_id of this BankTransaction.
        :type: str
        """
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def flow_direction(self):
        """Gets the flow_direction of this BankTransaction.

            

        :return: The flow_direction of this BankTransaction.
        :rtype: BankTransactionFlowDirection
        """
        return self._flow_direction

    @flow_direction.setter
    def flow_direction(self, flow_direction):
        """Sets the flow_direction of this BankTransaction.

            

        :param flow_direction: The flow_direction of this BankTransaction.
        :type: BankTransactionFlowDirection
        """

        self._flow_direction = flow_direction
    
    @property
    def id(self):
        """Gets the id of this BankTransaction.

            A unique identifier for the object.

        :return: The id of this BankTransaction.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BankTransaction.

            A unique identifier for the object.

        :param id: The id of this BankTransaction.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this BankTransaction.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this BankTransaction.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this BankTransaction.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this BankTransaction.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this BankTransaction.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this BankTransaction.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this BankTransaction.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this BankTransaction.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def posting_amount(self):
        """Gets the posting_amount of this BankTransaction.

            The posting amount indicates the amount including adjustments.

        :return: The posting_amount of this BankTransaction.
        :rtype: float
        """
        return self._posting_amount

    @posting_amount.setter
    def posting_amount(self, posting_amount):
        """Sets the posting_amount of this BankTransaction.

            The posting amount indicates the amount including adjustments.

        :param posting_amount: The posting_amount of this BankTransaction.
        :type: float
        """

        self._posting_amount = posting_amount
    
    @property
    def reference(self):
        """Gets the reference of this BankTransaction.

            

        :return: The reference of this BankTransaction.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this BankTransaction.

            

        :param reference: The reference of this BankTransaction.
        :type: str
        """

        self._reference = reference
    
    @property
    def source(self):
        """Gets the source of this BankTransaction.

            

        :return: The source of this BankTransaction.
        :rtype: int
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this BankTransaction.

            

        :param source: The source of this BankTransaction.
        :type: int
        """

        self._source = source
    
    @property
    def state(self):
        """Gets the state of this BankTransaction.

            The object's current state.

        :return: The state of this BankTransaction.
        :rtype: BankTransactionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BankTransaction.

            The object's current state.

        :param state: The state of this BankTransaction.
        :type: BankTransactionState
        """

        self._state = state
    
    @property
    def total_adjustment_amount_including_tax(self):
        """Gets the total_adjustment_amount_including_tax of this BankTransaction.

            

        :return: The total_adjustment_amount_including_tax of this BankTransaction.
        :rtype: float
        """
        return self._total_adjustment_amount_including_tax

    @total_adjustment_amount_including_tax.setter
    def total_adjustment_amount_including_tax(self, total_adjustment_amount_including_tax):
        """Sets the total_adjustment_amount_including_tax of this BankTransaction.

            

        :param total_adjustment_amount_including_tax: The total_adjustment_amount_including_tax of this BankTransaction.
        :type: float
        """

        self._total_adjustment_amount_including_tax = total_adjustment_amount_including_tax
    
    @property
    def type(self):
        """Gets the type of this BankTransaction.

            

        :return: The type of this BankTransaction.
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BankTransaction.

            

        :param type: The type of this BankTransaction.
        :type: int
        """

        self._type = type
    
    @property
    def value_amount(self):
        """Gets the value_amount of this BankTransaction.

            

        :return: The value_amount of this BankTransaction.
        :rtype: float
        """
        return self._value_amount

    @value_amount.setter
    def value_amount(self, value_amount):
        """Sets the value_amount of this BankTransaction.

            

        :param value_amount: The value_amount of this BankTransaction.
        :type: float
        """

        self._value_amount = value_amount
    
    @property
    def value_date(self):
        """Gets the value_date of this BankTransaction.

            The value date describes the date the amount is effective on the account.

        :return: The value_date of this BankTransaction.
        :rtype: datetime
        """
        return self._value_date

    @value_date.setter
    def value_date(self, value_date):
        """Sets the value_date of this BankTransaction.

            The value date describes the date the amount is effective on the account.

        :param value_date: The value_date of this BankTransaction.
        :type: datetime
        """

        self._value_date = value_date
    
    @property
    def version(self):
        """Gets the version of this BankTransaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this BankTransaction.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BankTransaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this BankTransaction.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(BankTransaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, BankTransaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



import base64
import binascii

from cryptography.exceptions import InvalidSignature
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.asymmetric import ec
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import hashes


class EncryptionUtil:
    @staticmethod
    def is_content_valid(content, signature, public_key, encryption_algorithm):
        algorithm_class = EncryptionUtil._get_algorithm_class(encryption_algorithm)
        if algorithm_class is None:
            raise ValueError(f"Unsupported algorithm: {encryption_algorithm}")

        try:
            signature = base64.b64decode(signature)
        except binascii.Error:
            raise ValueError("Invalid signature value format")

        try:
            public_key_bytes = base64.b64decode(public_key)
        except binascii.Error:
            raise ValueError("Invalid public key value format")

        public_key = serialization.load_der_public_key(public_key_bytes, backend=default_backend())

        try:
            public_key.verify(
                signature,
                content.encode('utf-8'),
                algorithm_class(hashes.SHA256())
            )
            return True
        except InvalidSignature:
            return False

    @staticmethod
    def _get_algorithm_class(algorithm):
        switch = {
            'SHA256withECDSA': ec.ECDSA,
        }
        return switch.get(algorithm, None)


# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentLink:

    swagger_types = {
    
        'allowed_payment_method_configurations': 'list[PaymentMethodConfiguration]',
        'applied_space_view': 'int',
        'available_from': 'datetime',
        'available_until': 'datetime',
        'billing_address_handling_mode': 'PaymentLinkAddressHandlingMode',
        'currency': 'str',
        'external_id': 'str',
        'id': 'int',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'maximal_number_of_transactions': 'int',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'protection_mode': 'PaymentLinkProtectionMode',
        'shipping_address_handling_mode': 'PaymentLinkAddressHandlingMode',
        'state': 'CreationEntityState',
        'url': 'str',
        'version': 'int',
    }

    attribute_map = {
        'allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','applied_space_view': 'appliedSpaceView','available_from': 'availableFrom','available_until': 'availableUntil','billing_address_handling_mode': 'billingAddressHandlingMode','currency': 'currency','external_id': 'externalId','id': 'id','language': 'language','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','maximal_number_of_transactions': 'maximalNumberOfTransactions','name': 'name','planned_purge_date': 'plannedPurgeDate','protection_mode': 'protectionMode','shipping_address_handling_mode': 'shippingAddressHandlingMode','state': 'state','url': 'url','version': 'version',
    }

    
    _allowed_payment_method_configurations = None
    _applied_space_view = None
    _available_from = None
    _available_until = None
    _billing_address_handling_mode = None
    _currency = None
    _external_id = None
    _id = None
    _language = None
    _line_items = None
    _linked_space_id = None
    _maximal_number_of_transactions = None
    _name = None
    _planned_purge_date = None
    _protection_mode = None
    _shipping_address_handling_mode = None
    _state = None
    _url = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.applied_space_view = kwargs.get('applied_space_view', None)
        self.available_from = kwargs.get('available_from', None)
        self.available_until = kwargs.get('available_until', None)
        self.billing_address_handling_mode = kwargs.get('billing_address_handling_mode', None)
        self.currency = kwargs.get('currency', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.maximal_number_of_transactions = kwargs.get('maximal_number_of_transactions', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.protection_mode = kwargs.get('protection_mode', None)
        self.shipping_address_handling_mode = kwargs.get('shipping_address_handling_mode', None)
        self.state = kwargs.get('state', None)
        self.url = kwargs.get('url', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this PaymentLink.

            The allowed payment method configurations restrict the payment methods which can be used with this payment link.

        :return: The allowed_payment_method_configurations of this PaymentLink.
        :rtype: list[PaymentMethodConfiguration]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this PaymentLink.

            The allowed payment method configurations restrict the payment methods which can be used with this payment link.

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this PaymentLink.
        :type: list[PaymentMethodConfiguration]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def applied_space_view(self):
        """Gets the applied_space_view of this PaymentLink.

            The payment link can be conducted in a specific space view. The space view may apply a specific design to the payment page.

        :return: The applied_space_view of this PaymentLink.
        :rtype: int
        """
        return self._applied_space_view

    @applied_space_view.setter
    def applied_space_view(self, applied_space_view):
        """Sets the applied_space_view of this PaymentLink.

            The payment link can be conducted in a specific space view. The space view may apply a specific design to the payment page.

        :param applied_space_view: The applied_space_view of this PaymentLink.
        :type: int
        """

        self._applied_space_view = applied_space_view
    
    @property
    def available_from(self):
        """Gets the available_from of this PaymentLink.

            The available from date defines the earliest date on which the payment link can be used. When no date is specified there will be no restriction.

        :return: The available_from of this PaymentLink.
        :rtype: datetime
        """
        return self._available_from

    @available_from.setter
    def available_from(self, available_from):
        """Sets the available_from of this PaymentLink.

            The available from date defines the earliest date on which the payment link can be used. When no date is specified there will be no restriction.

        :param available_from: The available_from of this PaymentLink.
        :type: datetime
        """

        self._available_from = available_from
    
    @property
    def available_until(self):
        """Gets the available_until of this PaymentLink.

            The available from date defines the latest date on which the payment link can be used to initialize a transaction. When no date is specified there will be no restriction.

        :return: The available_until of this PaymentLink.
        :rtype: datetime
        """
        return self._available_until

    @available_until.setter
    def available_until(self, available_until):
        """Sets the available_until of this PaymentLink.

            The available from date defines the latest date on which the payment link can be used to initialize a transaction. When no date is specified there will be no restriction.

        :param available_until: The available_until of this PaymentLink.
        :type: datetime
        """

        self._available_until = available_until
    
    @property
    def billing_address_handling_mode(self):
        """Gets the billing_address_handling_mode of this PaymentLink.

            The billing address handling mode controls if the address is collected or not and how it is collected.

        :return: The billing_address_handling_mode of this PaymentLink.
        :rtype: PaymentLinkAddressHandlingMode
        """
        return self._billing_address_handling_mode

    @billing_address_handling_mode.setter
    def billing_address_handling_mode(self, billing_address_handling_mode):
        """Sets the billing_address_handling_mode of this PaymentLink.

            The billing address handling mode controls if the address is collected or not and how it is collected.

        :param billing_address_handling_mode: The billing_address_handling_mode of this PaymentLink.
        :type: PaymentLinkAddressHandlingMode
        """

        self._billing_address_handling_mode = billing_address_handling_mode
    
    @property
    def currency(self):
        """Gets the currency of this PaymentLink.

            The currency defines in which currency the payment is executed in. If no currency is defined it has to be specified within the request parameter 'currency'.

        :return: The currency of this PaymentLink.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PaymentLink.

            The currency defines in which currency the payment is executed in. If no currency is defined it has to be specified within the request parameter 'currency'.

        :param currency: The currency of this PaymentLink.
        :type: str
        """

        self._currency = currency
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentLink.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this PaymentLink.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentLink.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this PaymentLink.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentLink.

            A unique identifier for the object.

        :return: The id of this PaymentLink.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentLink.

            A unique identifier for the object.

        :param id: The id of this PaymentLink.
        :type: int
        """

        self._id = id
    
    @property
    def language(self):
        """Gets the language of this PaymentLink.

            The language defines the language of the payment page. If no language is provided it can be provided through the request parameter.

        :return: The language of this PaymentLink.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this PaymentLink.

            The language defines the language of the payment page. If no language is provided it can be provided through the request parameter.

        :param language: The language of this PaymentLink.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this PaymentLink.

            The line items allows to define the line items for this payment link. When the line items are defined they cannot be overridden through the request parameters. If no amount for the payment link is defined, the additional checkout page to enter the amount is shown to the consumer.

        :return: The line_items of this PaymentLink.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this PaymentLink.

            The line items allows to define the line items for this payment link. When the line items are defined they cannot be overridden through the request parameters. If no amount for the payment link is defined, the additional checkout page to enter the amount is shown to the consumer.

        :param line_items: The line_items of this PaymentLink.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentLink.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentLink.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentLink.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentLink.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def maximal_number_of_transactions(self):
        """Gets the maximal_number_of_transactions of this PaymentLink.

            The maximal number of transactions limits the number of transactions which can be created with this payment link.

        :return: The maximal_number_of_transactions of this PaymentLink.
        :rtype: int
        """
        return self._maximal_number_of_transactions

    @maximal_number_of_transactions.setter
    def maximal_number_of_transactions(self, maximal_number_of_transactions):
        """Sets the maximal_number_of_transactions of this PaymentLink.

            The maximal number of transactions limits the number of transactions which can be created with this payment link.

        :param maximal_number_of_transactions: The maximal_number_of_transactions of this PaymentLink.
        :type: int
        """

        self._maximal_number_of_transactions = maximal_number_of_transactions
    
    @property
    def name(self):
        """Gets the name of this PaymentLink.

            The payment link name is used internally to identify the payment link. For example the name is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this PaymentLink.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentLink.

            The payment link name is used internally to identify the payment link. For example the name is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this PaymentLink.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentLink.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentLink.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentLink.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentLink.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def protection_mode(self):
        """Gets the protection_mode of this PaymentLink.

            The protection mode determines if the payment link is protected against tampering and in what way.

        :return: The protection_mode of this PaymentLink.
        :rtype: PaymentLinkProtectionMode
        """
        return self._protection_mode

    @protection_mode.setter
    def protection_mode(self, protection_mode):
        """Sets the protection_mode of this PaymentLink.

            The protection mode determines if the payment link is protected against tampering and in what way.

        :param protection_mode: The protection_mode of this PaymentLink.
        :type: PaymentLinkProtectionMode
        """

        self._protection_mode = protection_mode
    
    @property
    def shipping_address_handling_mode(self):
        """Gets the shipping_address_handling_mode of this PaymentLink.

            The shipping address handling mode controls if the address is collected or not and how it is collected.

        :return: The shipping_address_handling_mode of this PaymentLink.
        :rtype: PaymentLinkAddressHandlingMode
        """
        return self._shipping_address_handling_mode

    @shipping_address_handling_mode.setter
    def shipping_address_handling_mode(self, shipping_address_handling_mode):
        """Sets the shipping_address_handling_mode of this PaymentLink.

            The shipping address handling mode controls if the address is collected or not and how it is collected.

        :param shipping_address_handling_mode: The shipping_address_handling_mode of this PaymentLink.
        :type: PaymentLinkAddressHandlingMode
        """

        self._shipping_address_handling_mode = shipping_address_handling_mode
    
    @property
    def state(self):
        """Gets the state of this PaymentLink.

            The object's current state.

        :return: The state of this PaymentLink.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentLink.

            The object's current state.

        :param state: The state of this PaymentLink.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def url(self):
        """Gets the url of this PaymentLink.

            The URL defines the URL to which the user has to be forwarded to initialize the payment.

        :return: The url of this PaymentLink.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PaymentLink.

            The URL defines the URL to which the user has to be forwarded to initialize the payment.

        :param url: The url of this PaymentLink.
        :type: str
        """

        self._url = url
    
    @property
    def version(self):
        """Gets the version of this PaymentLink.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentLink.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentLink.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentLink.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentLink, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AnalyticsQueryResultBatch:

    swagger_types = {
    
        'columns': 'list[AnalyticsSchemaColumn]',
        'next_token': 'str',
        'query_execution': 'AnalyticsQueryExecution',
        'rows': 'list[list[str]]',
    }

    attribute_map = {
        'columns': 'columns','next_token': 'nextToken','query_execution': 'queryExecution','rows': 'rows',
    }

    
    _columns = None
    _next_token = None
    _query_execution = None
    _rows = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.columns = kwargs.get('columns', None)
        self.next_token = kwargs.get('next_token', None)
        self.query_execution = kwargs.get('query_execution', None)
        self.rows = kwargs.get('rows', None)
        

    
    @property
    def columns(self):
        """Gets the columns of this AnalyticsQueryResultBatch.

            The schemas of the columns returned by the query (in order). Will be null if the results of the query are not (yet) available.

        :return: The columns of this AnalyticsQueryResultBatch.
        :rtype: list[AnalyticsSchemaColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this AnalyticsQueryResultBatch.

            The schemas of the columns returned by the query (in order). Will be null if the results of the query are not (yet) available.

        :param columns: The columns of this AnalyticsQueryResultBatch.
        :type: list[AnalyticsSchemaColumn]
        """

        self._columns = columns
    
    @property
    def next_token(self):
        """Gets the next_token of this AnalyticsQueryResultBatch.

            The token to be provided to fetch the next batch of results. May be null if no more result batches are available.

        :return: The next_token of this AnalyticsQueryResultBatch.
        :rtype: str
        """
        return self._next_token

    @next_token.setter
    def next_token(self, next_token):
        """Sets the next_token of this AnalyticsQueryResultBatch.

            The token to be provided to fetch the next batch of results. May be null if no more result batches are available.

        :param next_token: The next_token of this AnalyticsQueryResultBatch.
        :type: str
        """

        self._next_token = next_token
    
    @property
    def query_execution(self):
        """Gets the query_execution of this AnalyticsQueryResultBatch.

            The query execution which produced the result.

        :return: The query_execution of this AnalyticsQueryResultBatch.
        :rtype: AnalyticsQueryExecution
        """
        return self._query_execution

    @query_execution.setter
    def query_execution(self, query_execution):
        """Sets the query_execution of this AnalyticsQueryResultBatch.

            The query execution which produced the result.

        :param query_execution: The query_execution of this AnalyticsQueryResultBatch.
        :type: AnalyticsQueryExecution
        """

        self._query_execution = query_execution
    
    @property
    def rows(self):
        """Gets the rows of this AnalyticsQueryResultBatch.

            The rows of the result set contained in this batch where each row is a list of column values (in order of the columns specified in the query). Will be null if the results of the query are not (yet) available.

        :return: The rows of this AnalyticsQueryResultBatch.
        :rtype: list[list[str]]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """Sets the rows of this AnalyticsQueryResultBatch.

            The rows of the result set contained in this batch where each row is a list of column values (in order of the columns specified in the query). Will be null if the results of the query are not (yet) available.

        :param rows: The rows of this AnalyticsQueryResultBatch.
        :type: list[list[str]]
        """

        self._rows = rows
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AnalyticsQueryResultBatch, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AnalyticsQueryResultBatch):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class InvoiceReconciliationRecordState(Enum):
    
    CREATE = "CREATE"
    PENDING = "PENDING"
    UNRESOLVED = "UNRESOLVED"
    RESOLVED = "RESOLVED"
    DISCARDED = "DISCARDED"




# coding: utf-8
import pprint
import six
from enum import Enum



class RestCurrency:

    swagger_types = {
    
        'currency_code': 'str',
        'fraction_digits': 'int',
        'name': 'str',
        'numeric_code': 'int',
    }

    attribute_map = {
        'currency_code': 'currencyCode','fraction_digits': 'fractionDigits','name': 'name','numeric_code': 'numericCode',
    }

    
    _currency_code = None
    _fraction_digits = None
    _name = None
    _numeric_code = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.currency_code = kwargs.get('currency_code', None)
        self.fraction_digits = kwargs.get('fraction_digits', None)
        self.name = kwargs.get('name', None)
        self.numeric_code = kwargs.get('numeric_code', None)
        

    
    @property
    def currency_code(self):
        """Gets the currency_code of this RestCurrency.

            The currency's three-letter code (ISO 4217 format).

        :return: The currency_code of this RestCurrency.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this RestCurrency.

            The currency's three-letter code (ISO 4217 format).

        :param currency_code: The currency_code of this RestCurrency.
        :type: str
        """

        self._currency_code = currency_code
    
    @property
    def fraction_digits(self):
        """Gets the fraction_digits of this RestCurrency.

            The currency's number of decimals. When calculating amounts in this currency, the fraction digits determine the accuracy.

        :return: The fraction_digits of this RestCurrency.
        :rtype: int
        """
        return self._fraction_digits

    @fraction_digits.setter
    def fraction_digits(self, fraction_digits):
        """Sets the fraction_digits of this RestCurrency.

            The currency's number of decimals. When calculating amounts in this currency, the fraction digits determine the accuracy.

        :param fraction_digits: The fraction_digits of this RestCurrency.
        :type: int
        """

        self._fraction_digits = fraction_digits
    
    @property
    def name(self):
        """Gets the name of this RestCurrency.

            The name of the currency.

        :return: The name of this RestCurrency.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RestCurrency.

            The name of the currency.

        :param name: The name of this RestCurrency.
        :type: str
        """

        self._name = name
    
    @property
    def numeric_code(self):
        """Gets the numeric_code of this RestCurrency.

            The currency's three-digit code (ISO 4217 format).

        :return: The numeric_code of this RestCurrency.
        :rtype: int
        """
        return self._numeric_code

    @numeric_code.setter
    def numeric_code(self, numeric_code):
        """Sets the numeric_code of this RestCurrency.

            The currency's three-digit code (ISO 4217 format).

        :param numeric_code: The numeric_code of this RestCurrency.
        :type: int
        """

        self._numeric_code = numeric_code
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RestCurrency, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RestCurrency):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionSuspensionCreate:

    swagger_types = {
    
        'end_action': 'SubscriptionSuspensionAction',
        'note': 'str',
        'planned_end_date': 'datetime',
        'subscription': 'int',
    }

    attribute_map = {
        'end_action': 'endAction','note': 'note','planned_end_date': 'plannedEndDate','subscription': 'subscription',
    }

    
    _end_action = None
    _note = None
    _planned_end_date = None
    _subscription = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.end_action = kwargs.get('end_action')

        self.note = kwargs.get('note', None)
        self.planned_end_date = kwargs.get('planned_end_date')

        self.subscription = kwargs.get('subscription')

        

    
    @property
    def end_action(self):
        """Gets the end_action of this SubscriptionSuspensionCreate.

            When the suspension reaches the planned end date the end action will be carried out. This action is only executed when the suspension is ended automatically based on the end date.

        :return: The end_action of this SubscriptionSuspensionCreate.
        :rtype: SubscriptionSuspensionAction
        """
        return self._end_action

    @end_action.setter
    def end_action(self, end_action):
        """Sets the end_action of this SubscriptionSuspensionCreate.

            When the suspension reaches the planned end date the end action will be carried out. This action is only executed when the suspension is ended automatically based on the end date.

        :param end_action: The end_action of this SubscriptionSuspensionCreate.
        :type: SubscriptionSuspensionAction
        """
        if end_action is None:
            raise ValueError("Invalid value for `end_action`, must not be `None`")

        self._end_action = end_action
    
    @property
    def note(self):
        """Gets the note of this SubscriptionSuspensionCreate.

            The note may contain some internal information for the suspension. The note will not be disclosed to the subscriber.

        :return: The note of this SubscriptionSuspensionCreate.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this SubscriptionSuspensionCreate.

            The note may contain some internal information for the suspension. The note will not be disclosed to the subscriber.

        :param note: The note of this SubscriptionSuspensionCreate.
        :type: str
        """
        if note is not None and len(note) > 300:
            raise ValueError("Invalid value for `note`, length must be less than or equal to `300`")

        self._note = note
    
    @property
    def planned_end_date(self):
        """Gets the planned_end_date of this SubscriptionSuspensionCreate.

            The planned end date of the suspension identifies the date on which the suspension will be ended automatically.

        :return: The planned_end_date of this SubscriptionSuspensionCreate.
        :rtype: datetime
        """
        return self._planned_end_date

    @planned_end_date.setter
    def planned_end_date(self, planned_end_date):
        """Sets the planned_end_date of this SubscriptionSuspensionCreate.

            The planned end date of the suspension identifies the date on which the suspension will be ended automatically.

        :param planned_end_date: The planned_end_date of this SubscriptionSuspensionCreate.
        :type: datetime
        """
        if planned_end_date is None:
            raise ValueError("Invalid value for `planned_end_date`, must not be `None`")

        self._planned_end_date = planned_end_date
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionSuspensionCreate.

            

        :return: The subscription of this SubscriptionSuspensionCreate.
        :rtype: int
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionSuspensionCreate.

            

        :param subscription: The subscription of this SubscriptionSuspensionCreate.
        :type: int
        """
        if subscription is None:
            raise ValueError("Invalid value for `subscription`, must not be `None`")

        self._subscription = subscription
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionSuspensionCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionSuspensionCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppConnector:

    swagger_types = {
    
        'authorization_timeout': 'str',
        'completion_configuration': 'PaymentAppCompletionConfiguration',
        'connector_configuration': 'PaymentConnectorConfiguration',
        'created_on': 'datetime',
        'external_id': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'payment_page_endpoint': 'str',
        'processor': 'PaymentAppProcessor',
        'refund_configuration': 'PaymentAppRefundConfiguration',
        'state': 'PaymentAppConnectorState',
        'updated_on': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'authorization_timeout': 'authorizationTimeout','completion_configuration': 'completionConfiguration','connector_configuration': 'connectorConfiguration','created_on': 'createdOn','external_id': 'externalId','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','payment_page_endpoint': 'paymentPageEndpoint','processor': 'processor','refund_configuration': 'refundConfiguration','state': 'state','updated_on': 'updatedOn','version': 'version',
    }

    
    _authorization_timeout = None
    _completion_configuration = None
    _connector_configuration = None
    _created_on = None
    _external_id = None
    _id = None
    _linked_space_id = None
    _name = None
    _payment_page_endpoint = None
    _processor = None
    _refund_configuration = None
    _state = None
    _updated_on = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.authorization_timeout = kwargs.get('authorization_timeout', None)
        self.completion_configuration = kwargs.get('completion_configuration', None)
        self.connector_configuration = kwargs.get('connector_configuration', None)
        self.created_on = kwargs.get('created_on', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.payment_page_endpoint = kwargs.get('payment_page_endpoint', None)
        self.processor = kwargs.get('processor', None)
        self.refund_configuration = kwargs.get('refund_configuration', None)
        self.state = kwargs.get('state', None)
        self.updated_on = kwargs.get('updated_on', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def authorization_timeout(self):
        """Gets the authorization_timeout of this PaymentAppConnector.

            

        :return: The authorization_timeout of this PaymentAppConnector.
        :rtype: str
        """
        return self._authorization_timeout

    @authorization_timeout.setter
    def authorization_timeout(self, authorization_timeout):
        """Sets the authorization_timeout of this PaymentAppConnector.

            

        :param authorization_timeout: The authorization_timeout of this PaymentAppConnector.
        :type: str
        """

        self._authorization_timeout = authorization_timeout
    
    @property
    def completion_configuration(self):
        """Gets the completion_configuration of this PaymentAppConnector.

            The completion configuration defines how the deferred completion is processed. If it is not present it means that deferred completion is not supported by this connector.

        :return: The completion_configuration of this PaymentAppConnector.
        :rtype: PaymentAppCompletionConfiguration
        """
        return self._completion_configuration

    @completion_configuration.setter
    def completion_configuration(self, completion_configuration):
        """Sets the completion_configuration of this PaymentAppConnector.

            The completion configuration defines how the deferred completion is processed. If it is not present it means that deferred completion is not supported by this connector.

        :param completion_configuration: The completion_configuration of this PaymentAppConnector.
        :type: PaymentAppCompletionConfiguration
        """

        self._completion_configuration = completion_configuration
    
    @property
    def connector_configuration(self):
        """Gets the connector_configuration of this PaymentAppConnector.

            The connector configuration references the configuration that was created as part of this connector within the space. The connector configuration is referenced within transactions created with this connector.

        :return: The connector_configuration of this PaymentAppConnector.
        :rtype: PaymentConnectorConfiguration
        """
        return self._connector_configuration

    @connector_configuration.setter
    def connector_configuration(self, connector_configuration):
        """Sets the connector_configuration of this PaymentAppConnector.

            The connector configuration references the configuration that was created as part of this connector within the space. The connector configuration is referenced within transactions created with this connector.

        :param connector_configuration: The connector_configuration of this PaymentAppConnector.
        :type: PaymentConnectorConfiguration
        """

        self._connector_configuration = connector_configuration
    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentAppConnector.

            The created on date indicates when the connector was added.

        :return: The created_on of this PaymentAppConnector.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentAppConnector.

            The created on date indicates when the connector was added.

        :param created_on: The created_on of this PaymentAppConnector.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentAppConnector.

            The external ID corresponds to the ID provided during inserting of the processor.

        :return: The external_id of this PaymentAppConnector.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentAppConnector.

            The external ID corresponds to the ID provided during inserting of the processor.

        :param external_id: The external_id of this PaymentAppConnector.
        :type: str
        """
        if external_id is not None and len(external_id) > 40:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `40`")

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentAppConnector.

            A unique identifier for the object.

        :return: The id of this PaymentAppConnector.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentAppConnector.

            A unique identifier for the object.

        :param id: The id of this PaymentAppConnector.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentAppConnector.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentAppConnector.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentAppConnector.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentAppConnector.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentAppConnector.

            The name of the connector will be displayed within the user interfaces that the merchant is interacting with.

        :return: The name of this PaymentAppConnector.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentAppConnector.

            The name of the connector will be displayed within the user interfaces that the merchant is interacting with.

        :param name: The name of this PaymentAppConnector.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def payment_page_endpoint(self):
        """Gets the payment_page_endpoint of this PaymentAppConnector.

            The payment page endpoint is invoked to process the transaction. The endpoint is defined by the external service provider.

        :return: The payment_page_endpoint of this PaymentAppConnector.
        :rtype: str
        """
        return self._payment_page_endpoint

    @payment_page_endpoint.setter
    def payment_page_endpoint(self, payment_page_endpoint):
        """Sets the payment_page_endpoint of this PaymentAppConnector.

            The payment page endpoint is invoked to process the transaction. The endpoint is defined by the external service provider.

        :param payment_page_endpoint: The payment_page_endpoint of this PaymentAppConnector.
        :type: str
        """

        self._payment_page_endpoint = payment_page_endpoint
    
    @property
    def processor(self):
        """Gets the processor of this PaymentAppConnector.

            The processor references the app processor to which this connector belongs to. The relationship is established during the creation of the connector.

        :return: The processor of this PaymentAppConnector.
        :rtype: PaymentAppProcessor
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this PaymentAppConnector.

            The processor references the app processor to which this connector belongs to. The relationship is established during the creation of the connector.

        :param processor: The processor of this PaymentAppConnector.
        :type: PaymentAppProcessor
        """

        self._processor = processor
    
    @property
    def refund_configuration(self):
        """Gets the refund_configuration of this PaymentAppConnector.

            The refund configuration defines how refunds are processed. If it is not present it means that refunds are not supported by this connector.

        :return: The refund_configuration of this PaymentAppConnector.
        :rtype: PaymentAppRefundConfiguration
        """
        return self._refund_configuration

    @refund_configuration.setter
    def refund_configuration(self, refund_configuration):
        """Sets the refund_configuration of this PaymentAppConnector.

            The refund configuration defines how refunds are processed. If it is not present it means that refunds are not supported by this connector.

        :param refund_configuration: The refund_configuration of this PaymentAppConnector.
        :type: PaymentAppRefundConfiguration
        """

        self._refund_configuration = refund_configuration
    
    @property
    def state(self):
        """Gets the state of this PaymentAppConnector.

            The object's current state.

        :return: The state of this PaymentAppConnector.
        :rtype: PaymentAppConnectorState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentAppConnector.

            The object's current state.

        :param state: The state of this PaymentAppConnector.
        :type: PaymentAppConnectorState
        """

        self._state = state
    
    @property
    def updated_on(self):
        """Gets the updated_on of this PaymentAppConnector.

            The updated on date indicates when the last time the connector was updated on.

        :return: The updated_on of this PaymentAppConnector.
        :rtype: datetime
        """
        return self._updated_on

    @updated_on.setter
    def updated_on(self, updated_on):
        """Sets the updated_on of this PaymentAppConnector.

            The updated on date indicates when the last time the connector was updated on.

        :param updated_on: The updated_on of this PaymentAppConnector.
        :type: datetime
        """

        self._updated_on = updated_on
    
    @property
    def version(self):
        """Gets the version of this PaymentAppConnector.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentAppConnector.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentAppConnector.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentAppConnector.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppConnector, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppConnector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class ChargeFlowLevel(TransactionAwareEntity):

    swagger_types = {
    
        'asynchronous_charge': 'int',
        'configuration': 'ChargeFlowLevelConfiguration',
        'created_on': 'datetime',
        'planned_purge_date': 'datetime',
        'state': 'ChargeFlowLevelState',
        'synchronous_charge': 'int',
        'timeout_on': 'datetime',
        'token_charge': 'int',
        'transaction': 'Transaction',
        'version': 'int',
    }

    attribute_map = {
        'asynchronous_charge': 'asynchronousCharge','configuration': 'configuration','created_on': 'createdOn','planned_purge_date': 'plannedPurgeDate','state': 'state','synchronous_charge': 'synchronousCharge','timeout_on': 'timeoutOn','token_charge': 'tokenCharge','transaction': 'transaction','version': 'version',
    }

    
    _asynchronous_charge = None
    _configuration = None
    _created_on = None
    _planned_purge_date = None
    _state = None
    _synchronous_charge = None
    _timeout_on = None
    _token_charge = None
    _transaction = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.asynchronous_charge = kwargs.get('asynchronous_charge', None)
        self.configuration = kwargs.get('configuration', None)
        self.created_on = kwargs.get('created_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.synchronous_charge = kwargs.get('synchronous_charge', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.token_charge = kwargs.get('token_charge', None)
        self.transaction = kwargs.get('transaction', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def asynchronous_charge(self):
        """Gets the asynchronous_charge of this ChargeFlowLevel.

            

        :return: The asynchronous_charge of this ChargeFlowLevel.
        :rtype: int
        """
        return self._asynchronous_charge

    @asynchronous_charge.setter
    def asynchronous_charge(self, asynchronous_charge):
        """Sets the asynchronous_charge of this ChargeFlowLevel.

            

        :param asynchronous_charge: The asynchronous_charge of this ChargeFlowLevel.
        :type: int
        """

        self._asynchronous_charge = asynchronous_charge
    
    @property
    def configuration(self):
        """Gets the configuration of this ChargeFlowLevel.

            

        :return: The configuration of this ChargeFlowLevel.
        :rtype: ChargeFlowLevelConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this ChargeFlowLevel.

            

        :param configuration: The configuration of this ChargeFlowLevel.
        :type: ChargeFlowLevelConfiguration
        """

        self._configuration = configuration
    
    @property
    def created_on(self):
        """Gets the created_on of this ChargeFlowLevel.

            The date and time when the object was created.

        :return: The created_on of this ChargeFlowLevel.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ChargeFlowLevel.

            The date and time when the object was created.

        :param created_on: The created_on of this ChargeFlowLevel.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ChargeFlowLevel.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this ChargeFlowLevel.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ChargeFlowLevel.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this ChargeFlowLevel.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this ChargeFlowLevel.

            The object's current state.

        :return: The state of this ChargeFlowLevel.
        :rtype: ChargeFlowLevelState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ChargeFlowLevel.

            The object's current state.

        :param state: The state of this ChargeFlowLevel.
        :type: ChargeFlowLevelState
        """

        self._state = state
    
    @property
    def synchronous_charge(self):
        """Gets the synchronous_charge of this ChargeFlowLevel.

            

        :return: The synchronous_charge of this ChargeFlowLevel.
        :rtype: int
        """
        return self._synchronous_charge

    @synchronous_charge.setter
    def synchronous_charge(self, synchronous_charge):
        """Sets the synchronous_charge of this ChargeFlowLevel.

            

        :param synchronous_charge: The synchronous_charge of this ChargeFlowLevel.
        :type: int
        """

        self._synchronous_charge = synchronous_charge
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this ChargeFlowLevel.

            

        :return: The timeout_on of this ChargeFlowLevel.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this ChargeFlowLevel.

            

        :param timeout_on: The timeout_on of this ChargeFlowLevel.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def token_charge(self):
        """Gets the token_charge of this ChargeFlowLevel.

            

        :return: The token_charge of this ChargeFlowLevel.
        :rtype: int
        """
        return self._token_charge

    @token_charge.setter
    def token_charge(self, token_charge):
        """Sets the token_charge of this ChargeFlowLevel.

            

        :param token_charge: The token_charge of this ChargeFlowLevel.
        :type: int
        """

        self._token_charge = token_charge
    
    @property
    def transaction(self):
        """Gets the transaction of this ChargeFlowLevel.

            

        :return: The transaction of this ChargeFlowLevel.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this ChargeFlowLevel.

            

        :param transaction: The transaction of this ChargeFlowLevel.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def version(self):
        """Gets the version of this ChargeFlowLevel.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this ChargeFlowLevel.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ChargeFlowLevel.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this ChargeFlowLevel.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ChargeFlowLevel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ChargeFlowLevel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



import unittest

from constants import (
    API_CONFIG,
    SPACE_ID,
    get_transaction_create,
    FAKE_CARD_DATA,
    TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
    TEST_CUSTOMER_ID,
)

from wallee.api import (
    TransactionServiceApi,
    CardProcessingServiceApi,
    TokenServiceApi,
    TransactionCompletionServiceApi,
)
from wallee.models import (
    TransactionState,
    EntityQuery,
    EntityQueryFilter,
    EntityQueryFilterType,
    CriteriaOperator,
    TokenizationMode,
    TransactionCompletionBehavior,
    CustomersPresence,
    TransactionCompletionState,
)
from wallee.rest import ApiException


class TransactionServiceTest(unittest.TestCase):
    """TransactionServiceApi tests"""

    def setUp(self):
        self.transaction_service = TransactionServiceApi(API_CONFIG)
        self.transaction_completion_service = TransactionCompletionServiceApi(
            API_CONFIG)
        self.card_processing_service = CardProcessingServiceApi(API_CONFIG)
        self.token_service = TokenServiceApi(API_CONFIG)

    def tearDown(self):
        pass

    def test_create(self):
        """create() should create transaction"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        self.assertEqual(
            TransactionState.PENDING, transaction.state, "State must be PENDING"
        )

    def test_confirm(self):
        """confirm() should mark transaction as confirmed"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        transaction_confirmed = self.transaction_service.confirm(
            space_id=SPACE_ID, transaction_model=transaction)

        self.assertEqual(
            TransactionState.CONFIRMED,
            transaction_confirmed.state,
            "State must be CONFIRMED",
        )

    def test_create_complete_deferred(self):
        """create() with COMPLETE_DEFERRED transaction behaviour should make transaction Authorized when we pay with card details"""

        transaction_create = get_transaction_create()
        transaction_create.tokenization_mode = TokenizationMode.FORCE_CREATION
        transaction_create.customers_presence = CustomersPresence.NOT_PRESENT
        transaction_create.completion_behavior = TransactionCompletionBehavior.COMPLETE_DEFERRED

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=transaction_create)
        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        self.assertEqual(
            TransactionState.AUTHORIZED,
            transaction_processed.state,
            "State must be AUTHORIZED",
        )

    def test_create_complete_immediately(self):
        """create() with COMPLETE_IMMEDIATELY transaction behaviour should make transaction Fulfilled when we pay with card details"""

        transaction_create = get_transaction_create()
        transaction_create.tokenization_mode = TokenizationMode.FORCE_CREATION
        transaction_create.customers_presence = CustomersPresence.NOT_PRESENT
        transaction_create.completion_behavior = TransactionCompletionBehavior.COMPLETE_IMMEDIATELY

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=transaction_create)

        transaction_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        self.assertEqual(TransactionState.FULFILL,
                         transaction_processed.state, "State must be FULFILL", )

    def test_count(self):
        """count() should count transactions matching given criteria"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        entity_query_filter = EntityQueryFilter(
            field_name="id",
            value=transaction.id,
            type=EntityQueryFilterType.LEAF,
            operator=CriteriaOperator.EQUALS,
        )

        transaction_count = self.transaction_service.count(
            space_id=SPACE_ID, filter=entity_query_filter)

        self.assertEqual(1, transaction_count, "Transaction count should be 1")

    def test_create_transaction_credentials(self):
        """create_transaction_credentials() should create valid transaction credentials token"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        creds = self.transaction_service.create_transaction_credentials(
            space_id=SPACE_ID, id=transaction.id)

        self.assertTrue(creds.startswith(str(SPACE_ID)),
                        "Transaction credentials token should have valid format", )

    def test_fetch_payment_methods(self):
        """fetch_payment_methods() should fetch payment methods available for the transaction"""
        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        payment_methods = self.transaction_service.fetch_payment_methods(
            space_id=SPACE_ID,
            id=transaction.id,
            integration_mode="payment_page",
        )

        self.assertTrue(len(payment_methods) > 0,
                        "Payment methods should be configured for a given transaction in test space", )

    def test_read(self):
        """read() should read transaction details"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        transaction_read = self.transaction_service.read(
            space_id=SPACE_ID, id=transaction.id)

        self.assertEqual(transaction.id, transaction_read.id,
                         "Transaction ids should match")

        self.assertEqual(TransactionState.PENDING,
                         transaction_read.state, "State must be PENDING")

    def test_read_with_credentials_for_bad_creds(self):
        """read_with_credentials() should fail when credentials are bad"""

        try:
            self.transaction_service.read_with_credentials(
                credentials="invalid_token")
        except ApiException as ex:
            self.assertEqual(
                442,
                ex.status,
                "Bad token should produce 442 Unprocessable content HTTP status response",
            )

    def test_read_with_credentials(self):
        """read_with_credentials() should read transaction when valid credentials token is provided"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        creds = self.transaction_service.create_transaction_credentials(
            space_id=SPACE_ID, id=transaction.id)

        transaction_read = self.transaction_service.read_with_credentials(
            credentials=creds)

        self.assertEqual(transaction.id, transaction_read.id,
                         "Transaction ids should match")

    def test_search(self):
        """search() should find transaction by id"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        entity_query_filter = EntityQueryFilter(
            field_name="id",
            value=transaction.id,
            type=EntityQueryFilterType.LEAF,
            operator=CriteriaOperator.EQUALS,
        )
        entity_query = EntityQuery(filter=entity_query_filter)

        transactions = self.transaction_service.search(
            space_id=SPACE_ID, query=entity_query)

        self.assertEqual(1, len(transactions))
        for transaction_found in transactions:
            self.assertEqual(transaction.id, transaction_found.id)

    def test_update(self):
        """update() should successfully update existing transaction"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())
        transaction.language = "en-US"
        transaction_update = self.transaction_service.update(
            space_id=SPACE_ID, entity=transaction)
        self.assertEqual("en-US", transaction_update.language)

    def test_process_without_user_interaction(self):
        """process_without_user_interaction() should correctly process created transaction without need for user interaction"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        transaction_processed = self.transaction_service.process_without_user_interaction(
            space_id=SPACE_ID, id=transaction.id)

        self.assertEqual(
            transaction.id, transaction_processed.id, "Transaction ids mush match"
        )

    def test_fetch_one_click_tokens_with_credentials_no_tokens(self):
        """fetch_one_click_tokens_with_credentials() should return one-click payment tokens (if any) for provided transaction"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        creds = self.transaction_service.create_transaction_credentials(
            space_id=SPACE_ID, id=transaction.id)

        tokens = self.transaction_service.fetch_one_click_tokens_with_credentials(
            creds)

        self.assertEqual(0, len(tokens), "Should be no tokens yet")

    def test_fetch_payment_methods_with_credentials(self):
        """fetch_one_click_tokens_with_credentials() should return one-click payment tokens (if any) for provided transaction"""

        transaction = self.transaction_service.create(
            space_id=SPACE_ID, transaction=get_transaction_create())

        creds = self.transaction_service.create_transaction_credentials(
            space_id=SPACE_ID, id=transaction.id)

        methods = self.transaction_service.fetch_payment_methods_with_credentials(
            credentials=creds, integration_mode="payment_page")

        self.assertTrue(len(methods) > 0,
                        "Should have some payment methods set up")

    def test_process_one_click_token_and_redirect_with_credentials(self):
        """process_one_click_token_and_redirect_with_credentials() should create URL that can be used to authorize 2nd transaction after we have created token for 1st authorized transaction"""

        transaction1_create = get_transaction_create()
        transaction1_create.tokenization_mode = TokenizationMode.FORCE_CREATION_WITH_ONE_CLICK_PAYMENT

        transaction1_create.customers_presence = CustomersPresence.NOT_PRESENT
        transaction1_create.completion_behavior = TransactionCompletionBehavior.COMPLETE_DEFERRED

        transaction1_create.customer_id = TEST_CUSTOMER_ID

        transaction1 = self.transaction_service.create(
            space_id=SPACE_ID, transaction=transaction1_create)

        transaction1_processed = self.card_processing_service.process(
            space_id=SPACE_ID,
            transaction_id=transaction1.id,
            payment_method_configuration_id=TEST_CARD_PAYMENT_METHOD_CONFIGURATION_ID,
            card_data=FAKE_CARD_DATA,
        )

        token = self.token_service.create_token(
            space_id=SPACE_ID, transaction_id=transaction1_processed.id)
        token.enabled_for_one_click_payment = True
        updated_token = self.token_service.update(
            space_id=SPACE_ID, entity=token
        )

        transaction2_create = get_transaction_create()
        transaction2_create.tokenization_mode = TokenizationMode.FORCE_CREATION_WITH_ONE_CLICK_PAYMENT
        transaction2_create.customers_presence = CustomersPresence.NOT_PRESENT
        transaction2_create.completion_behavior = TransactionCompletionBehavior.COMPLETE_DEFERRED
        transaction2_create.customer_id = TEST_CUSTOMER_ID

        transaction2 = self.transaction_service.create(
            space_id=SPACE_ID, transaction=transaction2_create)
        creds2 = self.transaction_service.create_transaction_credentials(
            space_id=SPACE_ID, id=transaction2.id)
        payment_url2 = self.transaction_service.process_one_click_token_and_redirect_with_credentials(
            credentials=creds2, token_id=updated_token.id)

        self.assertTrue("securityToken" in payment_url2,
                        "URL must be of a proper format")

        transaction2_read = self.transaction_service.read(
            space_id=SPACE_ID, id=transaction2.id)

        self.assertEqual(
            TransactionState.AUTHORIZED,
            transaction2_read.state,
            "State must be AUTHORIZED",
        )

        # cleanup - 2nd transaction
        transaction2_completed = self.transaction_completion_service.complete_online(
            space_id=SPACE_ID, id=transaction2.id)

        self.assertEqual(TransactionCompletionState.SUCCESSFUL,
                         transaction2_completed.state, "State must be SUCCESSFUL", )

        # cleanup - 1st transaction
        transaction1_completed = self.transaction_completion_service.complete_online(
            space_id=SPACE_ID, id=transaction1.id)

        self.assertEqual(TransactionCompletionState.SUCCESSFUL,
                         transaction1_completed.state, "State must be SUCCESSFUL", )

        self.token_service.delete(SPACE_ID, token.id)


if __name__ == "__main__":
    unittest.main(failfast=True)



# coding: utf-8
from enum import Enum, unique


@unique
class TokenizationMode(Enum):
    
    FORCE_UPDATE = "FORCE_UPDATE"
    FORCE_CREATION = "FORCE_CREATION"
    FORCE_CREATION_WITH_ONE_CLICK_PAYMENT = "FORCE_CREATION_WITH_ONE_CLICK_PAYMENT"
    ALLOW_ONE_CLICK_PAYMENT = "ALLOW_ONE_CLICK_PAYMENT"




# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractTransactionPending:

    swagger_types = {
    
        'allowed_payment_method_brands': 'list[int]',
        'allowed_payment_method_configurations': 'list[int]',
        'billing_address': 'AddressCreate',
        'completion_behavior': 'TransactionCompletionBehavior',
        'currency': 'str',
        'customer_email_address': 'str',
        'customer_id': 'str',
        'failed_url': 'str',
        'invoice_merchant_reference': 'str',
        'language': 'str',
        'line_items': 'list[LineItemCreate]',
        'merchant_reference': 'str',
        'meta_data': 'dict(str, str)',
        'shipping_address': 'AddressCreate',
        'shipping_method': 'str',
        'success_url': 'str',
        'time_zone': 'str',
        'token': 'int',
        'tokenization_mode': 'TokenizationMode',
    }

    attribute_map = {
        'allowed_payment_method_brands': 'allowedPaymentMethodBrands','allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','billing_address': 'billingAddress','completion_behavior': 'completionBehavior','currency': 'currency','customer_email_address': 'customerEmailAddress','customer_id': 'customerId','failed_url': 'failedUrl','invoice_merchant_reference': 'invoiceMerchantReference','language': 'language','line_items': 'lineItems','merchant_reference': 'merchantReference','meta_data': 'metaData','shipping_address': 'shippingAddress','shipping_method': 'shippingMethod','success_url': 'successUrl','time_zone': 'timeZone','token': 'token','tokenization_mode': 'tokenizationMode',
    }

    
    _allowed_payment_method_brands = None
    _allowed_payment_method_configurations = None
    _billing_address = None
    _completion_behavior = None
    _currency = None
    _customer_email_address = None
    _customer_id = None
    _failed_url = None
    _invoice_merchant_reference = None
    _language = None
    _line_items = None
    _merchant_reference = None
    _meta_data = None
    _shipping_address = None
    _shipping_method = None
    _success_url = None
    _time_zone = None
    _token = None
    _tokenization_mode = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.allowed_payment_method_brands = kwargs.get('allowed_payment_method_brands', None)
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.completion_behavior = kwargs.get('completion_behavior', None)
        self.currency = kwargs.get('currency', None)
        self.customer_email_address = kwargs.get('customer_email_address', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.failed_url = kwargs.get('failed_url', None)
        self.invoice_merchant_reference = kwargs.get('invoice_merchant_reference', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.meta_data = kwargs.get('meta_data', None)
        self.shipping_address = kwargs.get('shipping_address', None)
        self.shipping_method = kwargs.get('shipping_method', None)
        self.success_url = kwargs.get('success_url', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.token = kwargs.get('token', None)
        self.tokenization_mode = kwargs.get('tokenization_mode', None)
        

    
    @property
    def allowed_payment_method_brands(self):
        """Gets the allowed_payment_method_brands of this AbstractTransactionPending.

            

        :return: The allowed_payment_method_brands of this AbstractTransactionPending.
        :rtype: list[int]
        """
        return self._allowed_payment_method_brands

    @allowed_payment_method_brands.setter
    def allowed_payment_method_brands(self, allowed_payment_method_brands):
        """Sets the allowed_payment_method_brands of this AbstractTransactionPending.

            

        :param allowed_payment_method_brands: The allowed_payment_method_brands of this AbstractTransactionPending.
        :type: list[int]
        """

        self._allowed_payment_method_brands = allowed_payment_method_brands
    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this AbstractTransactionPending.

            

        :return: The allowed_payment_method_configurations of this AbstractTransactionPending.
        :rtype: list[int]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this AbstractTransactionPending.

            

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this AbstractTransactionPending.
        :type: list[int]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def billing_address(self):
        """Gets the billing_address of this AbstractTransactionPending.

            

        :return: The billing_address of this AbstractTransactionPending.
        :rtype: AddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this AbstractTransactionPending.

            

        :param billing_address: The billing_address of this AbstractTransactionPending.
        :type: AddressCreate
        """

        self._billing_address = billing_address
    
    @property
    def completion_behavior(self):
        """Gets the completion_behavior of this AbstractTransactionPending.

            The completion behavior controls when the transaction is completed.

        :return: The completion_behavior of this AbstractTransactionPending.
        :rtype: TransactionCompletionBehavior
        """
        return self._completion_behavior

    @completion_behavior.setter
    def completion_behavior(self, completion_behavior):
        """Sets the completion_behavior of this AbstractTransactionPending.

            The completion behavior controls when the transaction is completed.

        :param completion_behavior: The completion_behavior of this AbstractTransactionPending.
        :type: TransactionCompletionBehavior
        """

        self._completion_behavior = completion_behavior
    
    @property
    def currency(self):
        """Gets the currency of this AbstractTransactionPending.

            

        :return: The currency of this AbstractTransactionPending.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this AbstractTransactionPending.

            

        :param currency: The currency of this AbstractTransactionPending.
        :type: str
        """

        self._currency = currency
    
    @property
    def customer_email_address(self):
        """Gets the customer_email_address of this AbstractTransactionPending.

            The customer email address is the email address of the customer. If no email address is provided on the shipping or billing address this address is used.

        :return: The customer_email_address of this AbstractTransactionPending.
        :rtype: str
        """
        return self._customer_email_address

    @customer_email_address.setter
    def customer_email_address(self, customer_email_address):
        """Sets the customer_email_address of this AbstractTransactionPending.

            The customer email address is the email address of the customer. If no email address is provided on the shipping or billing address this address is used.

        :param customer_email_address: The customer_email_address of this AbstractTransactionPending.
        :type: str
        """
        if customer_email_address is not None and len(customer_email_address) > 254:
            raise ValueError("Invalid value for `customer_email_address`, length must be less than or equal to `254`")

        self._customer_email_address = customer_email_address
    
    @property
    def customer_id(self):
        """Gets the customer_id of this AbstractTransactionPending.

            

        :return: The customer_id of this AbstractTransactionPending.
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this AbstractTransactionPending.

            

        :param customer_id: The customer_id of this AbstractTransactionPending.
        :type: str
        """

        self._customer_id = customer_id
    
    @property
    def failed_url(self):
        """Gets the failed_url of this AbstractTransactionPending.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :return: The failed_url of this AbstractTransactionPending.
        :rtype: str
        """
        return self._failed_url

    @failed_url.setter
    def failed_url(self, failed_url):
        """Sets the failed_url of this AbstractTransactionPending.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :param failed_url: The failed_url of this AbstractTransactionPending.
        :type: str
        """
        if failed_url is not None and len(failed_url) > 2000:
            raise ValueError("Invalid value for `failed_url`, length must be less than or equal to `2000`")
        if failed_url is not None and len(failed_url) < 9:
            raise ValueError("Invalid value for `failed_url`, length must be greater than or equal to `9`")

        self._failed_url = failed_url
    
    @property
    def invoice_merchant_reference(self):
        """Gets the invoice_merchant_reference of this AbstractTransactionPending.

            

        :return: The invoice_merchant_reference of this AbstractTransactionPending.
        :rtype: str
        """
        return self._invoice_merchant_reference

    @invoice_merchant_reference.setter
    def invoice_merchant_reference(self, invoice_merchant_reference):
        """Sets the invoice_merchant_reference of this AbstractTransactionPending.

            

        :param invoice_merchant_reference: The invoice_merchant_reference of this AbstractTransactionPending.
        :type: str
        """
        if invoice_merchant_reference is not None and len(invoice_merchant_reference) > 100:
            raise ValueError("Invalid value for `invoice_merchant_reference`, length must be less than or equal to `100`")

        self._invoice_merchant_reference = invoice_merchant_reference
    
    @property
    def language(self):
        """Gets the language of this AbstractTransactionPending.

            The language that is linked to the object.

        :return: The language of this AbstractTransactionPending.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractTransactionPending.

            The language that is linked to the object.

        :param language: The language of this AbstractTransactionPending.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this AbstractTransactionPending.

            

        :return: The line_items of this AbstractTransactionPending.
        :rtype: list[LineItemCreate]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this AbstractTransactionPending.

            

        :param line_items: The line_items of this AbstractTransactionPending.
        :type: list[LineItemCreate]
        """

        self._line_items = line_items
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this AbstractTransactionPending.

            

        :return: The merchant_reference of this AbstractTransactionPending.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this AbstractTransactionPending.

            

        :param merchant_reference: The merchant_reference of this AbstractTransactionPending.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def meta_data(self):
        """Gets the meta_data of this AbstractTransactionPending.

            Allow to store additional information about the object.

        :return: The meta_data of this AbstractTransactionPending.
        :rtype: dict(str, str)
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """Sets the meta_data of this AbstractTransactionPending.

            Allow to store additional information about the object.

        :param meta_data: The meta_data of this AbstractTransactionPending.
        :type: dict(str, str)
        """

        self._meta_data = meta_data
    
    @property
    def shipping_address(self):
        """Gets the shipping_address of this AbstractTransactionPending.

            

        :return: The shipping_address of this AbstractTransactionPending.
        :rtype: AddressCreate
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this AbstractTransactionPending.

            

        :param shipping_address: The shipping_address of this AbstractTransactionPending.
        :type: AddressCreate
        """

        self._shipping_address = shipping_address
    
    @property
    def shipping_method(self):
        """Gets the shipping_method of this AbstractTransactionPending.

            

        :return: The shipping_method of this AbstractTransactionPending.
        :rtype: str
        """
        return self._shipping_method

    @shipping_method.setter
    def shipping_method(self, shipping_method):
        """Sets the shipping_method of this AbstractTransactionPending.

            

        :param shipping_method: The shipping_method of this AbstractTransactionPending.
        :type: str
        """
        if shipping_method is not None and len(shipping_method) > 200:
            raise ValueError("Invalid value for `shipping_method`, length must be less than or equal to `200`")

        self._shipping_method = shipping_method
    
    @property
    def success_url(self):
        """Gets the success_url of this AbstractTransactionPending.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :return: The success_url of this AbstractTransactionPending.
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this AbstractTransactionPending.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :param success_url: The success_url of this AbstractTransactionPending.
        :type: str
        """
        if success_url is not None and len(success_url) > 2000:
            raise ValueError("Invalid value for `success_url`, length must be less than or equal to `2000`")
        if success_url is not None and len(success_url) < 9:
            raise ValueError("Invalid value for `success_url`, length must be greater than or equal to `9`")

        self._success_url = success_url
    
    @property
    def time_zone(self):
        """Gets the time_zone of this AbstractTransactionPending.

            The time zone defines in which time zone the customer is located in. The time zone may affects how dates are formatted when interacting with the customer.

        :return: The time_zone of this AbstractTransactionPending.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AbstractTransactionPending.

            The time zone defines in which time zone the customer is located in. The time zone may affects how dates are formatted when interacting with the customer.

        :param time_zone: The time_zone of this AbstractTransactionPending.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def token(self):
        """Gets the token of this AbstractTransactionPending.

            

        :return: The token of this AbstractTransactionPending.
        :rtype: int
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this AbstractTransactionPending.

            

        :param token: The token of this AbstractTransactionPending.
        :type: int
        """

        self._token = token
    
    @property
    def tokenization_mode(self):
        """Gets the tokenization_mode of this AbstractTransactionPending.

            The tokenization mode controls if and how the tokenization of payment information is applied to the transaction.

        :return: The tokenization_mode of this AbstractTransactionPending.
        :rtype: TokenizationMode
        """
        return self._tokenization_mode

    @tokenization_mode.setter
    def tokenization_mode(self, tokenization_mode):
        """Sets the tokenization_mode of this AbstractTransactionPending.

            The tokenization mode controls if and how the tokenization of payment information is applied to the transaction.

        :param tokenization_mode: The tokenization_mode of this AbstractTransactionPending.
        :type: TokenizationMode
        """

        self._tokenization_mode = tokenization_mode
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractTransactionPending, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractTransactionPending):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductVersion:

    swagger_types = {
    
        'activated_on': 'datetime',
        'billing_cycle': 'str',
        'comment': 'str',
        'created_on': 'datetime',
        'default_currency': 'str',
        'enabled_currencies': 'list[str]',
        'id': 'int',
        'increment_number': 'int',
        'linked_space_id': 'int',
        'minimal_number_of_periods': 'int',
        'name': 'dict(str, str)',
        'number_of_notice_periods': 'int',
        'obsoleted_on': 'datetime',
        'planned_purge_date': 'datetime',
        'product': 'SubscriptionProduct',
        'reference': 'str',
        'retiring_finished_on': 'datetime',
        'retiring_started_on': 'datetime',
        'state': 'SubscriptionProductVersionState',
        'tax_calculation': 'TaxCalculation',
        'version': 'int',
    }

    attribute_map = {
        'activated_on': 'activatedOn','billing_cycle': 'billingCycle','comment': 'comment','created_on': 'createdOn','default_currency': 'defaultCurrency','enabled_currencies': 'enabledCurrencies','id': 'id','increment_number': 'incrementNumber','linked_space_id': 'linkedSpaceId','minimal_number_of_periods': 'minimalNumberOfPeriods','name': 'name','number_of_notice_periods': 'numberOfNoticePeriods','obsoleted_on': 'obsoletedOn','planned_purge_date': 'plannedPurgeDate','product': 'product','reference': 'reference','retiring_finished_on': 'retiringFinishedOn','retiring_started_on': 'retiringStartedOn','state': 'state','tax_calculation': 'taxCalculation','version': 'version',
    }

    
    _activated_on = None
    _billing_cycle = None
    _comment = None
    _created_on = None
    _default_currency = None
    _enabled_currencies = None
    _id = None
    _increment_number = None
    _linked_space_id = None
    _minimal_number_of_periods = None
    _name = None
    _number_of_notice_periods = None
    _obsoleted_on = None
    _planned_purge_date = None
    _product = None
    _reference = None
    _retiring_finished_on = None
    _retiring_started_on = None
    _state = None
    _tax_calculation = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.activated_on = kwargs.get('activated_on', None)
        self.billing_cycle = kwargs.get('billing_cycle', None)
        self.comment = kwargs.get('comment', None)
        self.created_on = kwargs.get('created_on', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.enabled_currencies = kwargs.get('enabled_currencies', None)
        self.id = kwargs.get('id', None)
        self.increment_number = kwargs.get('increment_number', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.minimal_number_of_periods = kwargs.get('minimal_number_of_periods', None)
        self.name = kwargs.get('name', None)
        self.number_of_notice_periods = kwargs.get('number_of_notice_periods', None)
        self.obsoleted_on = kwargs.get('obsoleted_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.product = kwargs.get('product', None)
        self.reference = kwargs.get('reference', None)
        self.retiring_finished_on = kwargs.get('retiring_finished_on', None)
        self.retiring_started_on = kwargs.get('retiring_started_on', None)
        self.state = kwargs.get('state', None)
        self.tax_calculation = kwargs.get('tax_calculation', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def activated_on(self):
        """Gets the activated_on of this SubscriptionProductVersion.

            

        :return: The activated_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._activated_on

    @activated_on.setter
    def activated_on(self, activated_on):
        """Sets the activated_on of this SubscriptionProductVersion.

            

        :param activated_on: The activated_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._activated_on = activated_on
    
    @property
    def billing_cycle(self):
        """Gets the billing_cycle of this SubscriptionProductVersion.

            The billing cycle determines the rhythm with which the subscriber is billed. The charging may have different rhythm.

        :return: The billing_cycle of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._billing_cycle

    @billing_cycle.setter
    def billing_cycle(self, billing_cycle):
        """Sets the billing_cycle of this SubscriptionProductVersion.

            The billing cycle determines the rhythm with which the subscriber is billed. The charging may have different rhythm.

        :param billing_cycle: The billing_cycle of this SubscriptionProductVersion.
        :type: str
        """

        self._billing_cycle = billing_cycle
    
    @property
    def comment(self):
        """Gets the comment of this SubscriptionProductVersion.

            The comment allows to provide a internal comment for the version. It helps to document why a product was changed. The comment is not disclosed to the subscriber.

        :return: The comment of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SubscriptionProductVersion.

            The comment allows to provide a internal comment for the version. It helps to document why a product was changed. The comment is not disclosed to the subscriber.

        :param comment: The comment of this SubscriptionProductVersion.
        :type: str
        """

        self._comment = comment
    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionProductVersion.

            

        :return: The created_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionProductVersion.

            

        :param created_on: The created_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def default_currency(self):
        """Gets the default_currency of this SubscriptionProductVersion.

            The default currency has to be used in all fees.

        :return: The default_currency of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this SubscriptionProductVersion.

            The default currency has to be used in all fees.

        :param default_currency: The default_currency of this SubscriptionProductVersion.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def enabled_currencies(self):
        """Gets the enabled_currencies of this SubscriptionProductVersion.

            The currencies which are enabled can be selected to define component fees. Currencies which are not enabled cannot be used to define fees.

        :return: The enabled_currencies of this SubscriptionProductVersion.
        :rtype: list[str]
        """
        return self._enabled_currencies

    @enabled_currencies.setter
    def enabled_currencies(self, enabled_currencies):
        """Sets the enabled_currencies of this SubscriptionProductVersion.

            The currencies which are enabled can be selected to define component fees. Currencies which are not enabled cannot be used to define fees.

        :param enabled_currencies: The enabled_currencies of this SubscriptionProductVersion.
        :type: list[str]
        """

        self._enabled_currencies = enabled_currencies
    
    @property
    def id(self):
        """Gets the id of this SubscriptionProductVersion.

            A unique identifier for the object.

        :return: The id of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionProductVersion.

            A unique identifier for the object.

        :param id: The id of this SubscriptionProductVersion.
        :type: int
        """

        self._id = id
    
    @property
    def increment_number(self):
        """Gets the increment_number of this SubscriptionProductVersion.

            The increment number represents the version number incremented whenever a new version is activated.

        :return: The increment_number of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._increment_number

    @increment_number.setter
    def increment_number(self, increment_number):
        """Sets the increment_number of this SubscriptionProductVersion.

            The increment number represents the version number incremented whenever a new version is activated.

        :param increment_number: The increment_number of this SubscriptionProductVersion.
        :type: int
        """

        self._increment_number = increment_number
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionProductVersion.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionProductVersion.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionProductVersion.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def minimal_number_of_periods(self):
        """Gets the minimal_number_of_periods of this SubscriptionProductVersion.

            The minimal number of periods determines how long the subscription has to run before the subscription can be terminated.

        :return: The minimal_number_of_periods of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._minimal_number_of_periods

    @minimal_number_of_periods.setter
    def minimal_number_of_periods(self, minimal_number_of_periods):
        """Sets the minimal_number_of_periods of this SubscriptionProductVersion.

            The minimal number of periods determines how long the subscription has to run before the subscription can be terminated.

        :param minimal_number_of_periods: The minimal_number_of_periods of this SubscriptionProductVersion.
        :type: int
        """

        self._minimal_number_of_periods = minimal_number_of_periods
    
    @property
    def name(self):
        """Gets the name of this SubscriptionProductVersion.

            The product version name is the name of the product which is shown to the user for the version. When the visible product name should be changed for a particular product a new version has to be created which contains the new name of the product.

        :return: The name of this SubscriptionProductVersion.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionProductVersion.

            The product version name is the name of the product which is shown to the user for the version. When the visible product name should be changed for a particular product a new version has to be created which contains the new name of the product.

        :param name: The name of this SubscriptionProductVersion.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def number_of_notice_periods(self):
        """Gets the number_of_notice_periods of this SubscriptionProductVersion.

            The number of notice periods determines the number of periods which need to be paid between the request to terminate the subscription and the final period.

        :return: The number_of_notice_periods of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._number_of_notice_periods

    @number_of_notice_periods.setter
    def number_of_notice_periods(self, number_of_notice_periods):
        """Sets the number_of_notice_periods of this SubscriptionProductVersion.

            The number of notice periods determines the number of periods which need to be paid between the request to terminate the subscription and the final period.

        :param number_of_notice_periods: The number_of_notice_periods of this SubscriptionProductVersion.
        :type: int
        """

        self._number_of_notice_periods = number_of_notice_periods
    
    @property
    def obsoleted_on(self):
        """Gets the obsoleted_on of this SubscriptionProductVersion.

            

        :return: The obsoleted_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._obsoleted_on

    @obsoleted_on.setter
    def obsoleted_on(self, obsoleted_on):
        """Sets the obsoleted_on of this SubscriptionProductVersion.

            

        :param obsoleted_on: The obsoleted_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._obsoleted_on = obsoleted_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionProductVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionProductVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionProductVersion.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def product(self):
        """Gets the product of this SubscriptionProductVersion.

            Each product version is linked to a product.

        :return: The product of this SubscriptionProductVersion.
        :rtype: SubscriptionProduct
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this SubscriptionProductVersion.

            Each product version is linked to a product.

        :param product: The product of this SubscriptionProductVersion.
        :type: SubscriptionProduct
        """

        self._product = product
    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionProductVersion.

            The product version reference helps to identify the version. The reference is generated out of the product reference.

        :return: The reference of this SubscriptionProductVersion.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionProductVersion.

            The product version reference helps to identify the version. The reference is generated out of the product reference.

        :param reference: The reference of this SubscriptionProductVersion.
        :type: str
        """
        if reference is not None and len(reference) > 125:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `125`")

        self._reference = reference
    
    @property
    def retiring_finished_on(self):
        """Gets the retiring_finished_on of this SubscriptionProductVersion.

            

        :return: The retiring_finished_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._retiring_finished_on

    @retiring_finished_on.setter
    def retiring_finished_on(self, retiring_finished_on):
        """Sets the retiring_finished_on of this SubscriptionProductVersion.

            

        :param retiring_finished_on: The retiring_finished_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._retiring_finished_on = retiring_finished_on
    
    @property
    def retiring_started_on(self):
        """Gets the retiring_started_on of this SubscriptionProductVersion.

            

        :return: The retiring_started_on of this SubscriptionProductVersion.
        :rtype: datetime
        """
        return self._retiring_started_on

    @retiring_started_on.setter
    def retiring_started_on(self, retiring_started_on):
        """Sets the retiring_started_on of this SubscriptionProductVersion.

            

        :param retiring_started_on: The retiring_started_on of this SubscriptionProductVersion.
        :type: datetime
        """

        self._retiring_started_on = retiring_started_on
    
    @property
    def state(self):
        """Gets the state of this SubscriptionProductVersion.

            The object's current state.

        :return: The state of this SubscriptionProductVersion.
        :rtype: SubscriptionProductVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionProductVersion.

            The object's current state.

        :param state: The state of this SubscriptionProductVersion.
        :type: SubscriptionProductVersionState
        """

        self._state = state
    
    @property
    def tax_calculation(self):
        """Gets the tax_calculation of this SubscriptionProductVersion.

            Strategy that is used for tax calculation in fees.

        :return: The tax_calculation of this SubscriptionProductVersion.
        :rtype: TaxCalculation
        """
        return self._tax_calculation

    @tax_calculation.setter
    def tax_calculation(self, tax_calculation):
        """Sets the tax_calculation of this SubscriptionProductVersion.

            Strategy that is used for tax calculation in fees.

        :param tax_calculation: The tax_calculation of this SubscriptionProductVersion.
        :type: TaxCalculation
        """

        self._tax_calculation = tax_calculation
    
    @property
    def version(self):
        """Gets the version of this SubscriptionProductVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this SubscriptionProductVersion.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionProductVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this SubscriptionProductVersion.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentConnectorFeature:

    swagger_types = {
    
        'display_name': 'str',
        'feature': 'Feature',
        'id': 'int',
    }

    attribute_map = {
        'display_name': 'displayName','feature': 'feature','id': 'id',
    }

    
    _display_name = None
    _feature = None
    _id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.display_name = kwargs.get('display_name', None)
        self.feature = kwargs.get('feature', None)
        self.id = kwargs.get('id', None)
        

    
    @property
    def display_name(self):
        """Gets the display_name of this PaymentConnectorFeature.

            

        :return: The display_name of this PaymentConnectorFeature.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this PaymentConnectorFeature.

            

        :param display_name: The display_name of this PaymentConnectorFeature.
        :type: str
        """

        self._display_name = display_name
    
    @property
    def feature(self):
        """Gets the feature of this PaymentConnectorFeature.

            

        :return: The feature of this PaymentConnectorFeature.
        :rtype: Feature
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this PaymentConnectorFeature.

            

        :param feature: The feature of this PaymentConnectorFeature.
        :type: Feature
        """

        self._feature = feature
    
    @property
    def id(self):
        """Gets the id of this PaymentConnectorFeature.

            A unique identifier for the object.

        :return: The id of this PaymentConnectorFeature.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentConnectorFeature.

            A unique identifier for the object.

        :param id: The id of this PaymentConnectorFeature.
        :type: int
        """

        self._id = id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentConnectorFeature, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentConnectorFeature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionCharge:

    swagger_types = {
    
        'created_on': 'datetime',
        'discarded_by': 'int',
        'discarded_on': 'datetime',
        'external_id': 'str',
        'failed_on': 'datetime',
        'failed_url': 'str',
        'id': 'int',
        'language': 'str',
        'ledger_entries': 'list[SubscriptionLedgerEntry]',
        'linked_space_id': 'int',
        'planned_execution_date': 'datetime',
        'planned_purge_date': 'datetime',
        'processing_type': 'SubscriptionChargeProcessingType',
        'reference': 'str',
        'state': 'SubscriptionChargeState',
        'subscription': 'Subscription',
        'succeed_on': 'datetime',
        'success_url': 'str',
        'transaction': 'Transaction',
        'type': 'SubscriptionChargeType',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','discarded_by': 'discardedBy','discarded_on': 'discardedOn','external_id': 'externalId','failed_on': 'failedOn','failed_url': 'failedUrl','id': 'id','language': 'language','ledger_entries': 'ledgerEntries','linked_space_id': 'linkedSpaceId','planned_execution_date': 'plannedExecutionDate','planned_purge_date': 'plannedPurgeDate','processing_type': 'processingType','reference': 'reference','state': 'state','subscription': 'subscription','succeed_on': 'succeedOn','success_url': 'successUrl','transaction': 'transaction','type': 'type','version': 'version',
    }

    
    _created_on = None
    _discarded_by = None
    _discarded_on = None
    _external_id = None
    _failed_on = None
    _failed_url = None
    _id = None
    _language = None
    _ledger_entries = None
    _linked_space_id = None
    _planned_execution_date = None
    _planned_purge_date = None
    _processing_type = None
    _reference = None
    _state = None
    _subscription = None
    _succeed_on = None
    _success_url = None
    _transaction = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.discarded_by = kwargs.get('discarded_by', None)
        self.discarded_on = kwargs.get('discarded_on', None)
        self.external_id = kwargs.get('external_id', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failed_url = kwargs.get('failed_url', None)
        self.id = kwargs.get('id', None)
        self.language = kwargs.get('language', None)
        self.ledger_entries = kwargs.get('ledger_entries', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_execution_date = kwargs.get('planned_execution_date', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processing_type = kwargs.get('processing_type', None)
        self.reference = kwargs.get('reference', None)
        self.state = kwargs.get('state', None)
        self.subscription = kwargs.get('subscription', None)
        self.succeed_on = kwargs.get('succeed_on', None)
        self.success_url = kwargs.get('success_url', None)
        self.transaction = kwargs.get('transaction', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionCharge.

            

        :return: The created_on of this SubscriptionCharge.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionCharge.

            

        :param created_on: The created_on of this SubscriptionCharge.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def discarded_by(self):
        """Gets the discarded_by of this SubscriptionCharge.

            

        :return: The discarded_by of this SubscriptionCharge.
        :rtype: int
        """
        return self._discarded_by

    @discarded_by.setter
    def discarded_by(self, discarded_by):
        """Sets the discarded_by of this SubscriptionCharge.

            

        :param discarded_by: The discarded_by of this SubscriptionCharge.
        :type: int
        """

        self._discarded_by = discarded_by
    
    @property
    def discarded_on(self):
        """Gets the discarded_on of this SubscriptionCharge.

            

        :return: The discarded_on of this SubscriptionCharge.
        :rtype: datetime
        """
        return self._discarded_on

    @discarded_on.setter
    def discarded_on(self, discarded_on):
        """Sets the discarded_on of this SubscriptionCharge.

            

        :param discarded_on: The discarded_on of this SubscriptionCharge.
        :type: datetime
        """

        self._discarded_on = discarded_on
    
    @property
    def external_id(self):
        """Gets the external_id of this SubscriptionCharge.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this SubscriptionCharge.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this SubscriptionCharge.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this SubscriptionCharge.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def failed_on(self):
        """Gets the failed_on of this SubscriptionCharge.

            

        :return: The failed_on of this SubscriptionCharge.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this SubscriptionCharge.

            

        :param failed_on: The failed_on of this SubscriptionCharge.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failed_url(self):
        """Gets the failed_url of this SubscriptionCharge.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :return: The failed_url of this SubscriptionCharge.
        :rtype: str
        """
        return self._failed_url

    @failed_url.setter
    def failed_url(self, failed_url):
        """Sets the failed_url of this SubscriptionCharge.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :param failed_url: The failed_url of this SubscriptionCharge.
        :type: str
        """
        if failed_url is not None and len(failed_url) > 500:
            raise ValueError("Invalid value for `failed_url`, length must be less than or equal to `500`")
        if failed_url is not None and len(failed_url) < 9:
            raise ValueError("Invalid value for `failed_url`, length must be greater than or equal to `9`")

        self._failed_url = failed_url
    
    @property
    def id(self):
        """Gets the id of this SubscriptionCharge.

            A unique identifier for the object.

        :return: The id of this SubscriptionCharge.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionCharge.

            A unique identifier for the object.

        :param id: The id of this SubscriptionCharge.
        :type: int
        """

        self._id = id
    
    @property
    def language(self):
        """Gets the language of this SubscriptionCharge.

            The language that is linked to the object.

        :return: The language of this SubscriptionCharge.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this SubscriptionCharge.

            The language that is linked to the object.

        :param language: The language of this SubscriptionCharge.
        :type: str
        """

        self._language = language
    
    @property
    def ledger_entries(self):
        """Gets the ledger_entries of this SubscriptionCharge.

            

        :return: The ledger_entries of this SubscriptionCharge.
        :rtype: list[SubscriptionLedgerEntry]
        """
        return self._ledger_entries

    @ledger_entries.setter
    def ledger_entries(self, ledger_entries):
        """Sets the ledger_entries of this SubscriptionCharge.

            

        :param ledger_entries: The ledger_entries of this SubscriptionCharge.
        :type: list[SubscriptionLedgerEntry]
        """

        self._ledger_entries = ledger_entries
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionCharge.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this SubscriptionCharge.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionCharge.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionCharge.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_execution_date(self):
        """Gets the planned_execution_date of this SubscriptionCharge.

            

        :return: The planned_execution_date of this SubscriptionCharge.
        :rtype: datetime
        """
        return self._planned_execution_date

    @planned_execution_date.setter
    def planned_execution_date(self, planned_execution_date):
        """Sets the planned_execution_date of this SubscriptionCharge.

            

        :param planned_execution_date: The planned_execution_date of this SubscriptionCharge.
        :type: datetime
        """

        self._planned_execution_date = planned_execution_date
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionCharge.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this SubscriptionCharge.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionCharge.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionCharge.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processing_type(self):
        """Gets the processing_type of this SubscriptionCharge.

            

        :return: The processing_type of this SubscriptionCharge.
        :rtype: SubscriptionChargeProcessingType
        """
        return self._processing_type

    @processing_type.setter
    def processing_type(self, processing_type):
        """Sets the processing_type of this SubscriptionCharge.

            

        :param processing_type: The processing_type of this SubscriptionCharge.
        :type: SubscriptionChargeProcessingType
        """

        self._processing_type = processing_type
    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionCharge.

            

        :return: The reference of this SubscriptionCharge.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionCharge.

            

        :param reference: The reference of this SubscriptionCharge.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def state(self):
        """Gets the state of this SubscriptionCharge.

            The object's current state.

        :return: The state of this SubscriptionCharge.
        :rtype: SubscriptionChargeState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionCharge.

            The object's current state.

        :param state: The state of this SubscriptionCharge.
        :type: SubscriptionChargeState
        """

        self._state = state
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionCharge.

            The field subscription indicates the subscription to which the charge belongs to.

        :return: The subscription of this SubscriptionCharge.
        :rtype: Subscription
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionCharge.

            The field subscription indicates the subscription to which the charge belongs to.

        :param subscription: The subscription of this SubscriptionCharge.
        :type: Subscription
        """

        self._subscription = subscription
    
    @property
    def succeed_on(self):
        """Gets the succeed_on of this SubscriptionCharge.

            

        :return: The succeed_on of this SubscriptionCharge.
        :rtype: datetime
        """
        return self._succeed_on

    @succeed_on.setter
    def succeed_on(self, succeed_on):
        """Sets the succeed_on of this SubscriptionCharge.

            

        :param succeed_on: The succeed_on of this SubscriptionCharge.
        :type: datetime
        """

        self._succeed_on = succeed_on
    
    @property
    def success_url(self):
        """Gets the success_url of this SubscriptionCharge.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :return: The success_url of this SubscriptionCharge.
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this SubscriptionCharge.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :param success_url: The success_url of this SubscriptionCharge.
        :type: str
        """
        if success_url is not None and len(success_url) > 500:
            raise ValueError("Invalid value for `success_url`, length must be less than or equal to `500`")
        if success_url is not None and len(success_url) < 9:
            raise ValueError("Invalid value for `success_url`, length must be greater than or equal to `9`")

        self._success_url = success_url
    
    @property
    def transaction(self):
        """Gets the transaction of this SubscriptionCharge.

            

        :return: The transaction of this SubscriptionCharge.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this SubscriptionCharge.

            

        :param transaction: The transaction of this SubscriptionCharge.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def type(self):
        """Gets the type of this SubscriptionCharge.

            

        :return: The type of this SubscriptionCharge.
        :rtype: SubscriptionChargeType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SubscriptionCharge.

            

        :param type: The type of this SubscriptionCharge.
        :type: SubscriptionChargeType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this SubscriptionCharge.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this SubscriptionCharge.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionCharge.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this SubscriptionCharge.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionCharge, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionCharge):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppCompletionConfigurationCreate:

    swagger_types = {
    
        'completion_endpoint': 'str',
        'completion_timeout_in_minutes': 'int',
        'maximal_completion_delay_in_days': 'int',
        'multiple_completions_supported': 'bool',
        'void_endpoint': 'str',
    }

    attribute_map = {
        'completion_endpoint': 'completionEndpoint','completion_timeout_in_minutes': 'completionTimeoutInMinutes','maximal_completion_delay_in_days': 'maximalCompletionDelayInDays','multiple_completions_supported': 'multipleCompletionsSupported','void_endpoint': 'voidEndpoint',
    }

    
    _completion_endpoint = None
    _completion_timeout_in_minutes = None
    _maximal_completion_delay_in_days = None
    _multiple_completions_supported = None
    _void_endpoint = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.completion_endpoint = kwargs.get('completion_endpoint', None)
        self.completion_timeout_in_minutes = kwargs.get('completion_timeout_in_minutes', None)
        self.maximal_completion_delay_in_days = kwargs.get('maximal_completion_delay_in_days', None)
        self.multiple_completions_supported = kwargs.get('multiple_completions_supported', None)
        self.void_endpoint = kwargs.get('void_endpoint', None)
        

    
    @property
    def completion_endpoint(self):
        """Gets the completion_endpoint of this PaymentAppCompletionConfigurationCreate.

            The completion endpoint is invoked to request the payment service provider to execute a completion.

        :return: The completion_endpoint of this PaymentAppCompletionConfigurationCreate.
        :rtype: str
        """
        return self._completion_endpoint

    @completion_endpoint.setter
    def completion_endpoint(self, completion_endpoint):
        """Sets the completion_endpoint of this PaymentAppCompletionConfigurationCreate.

            The completion endpoint is invoked to request the payment service provider to execute a completion.

        :param completion_endpoint: The completion_endpoint of this PaymentAppCompletionConfigurationCreate.
        :type: str
        """

        self._completion_endpoint = completion_endpoint
    
    @property
    def completion_timeout_in_minutes(self):
        """Gets the completion_timeout_in_minutes of this PaymentAppCompletionConfigurationCreate.

            When the completion or the void is triggered we expect a feedback about the state of it. This timeout defines after how long we consider the void resp. completion as failed without receiving a final state update.

        :return: The completion_timeout_in_minutes of this PaymentAppCompletionConfigurationCreate.
        :rtype: int
        """
        return self._completion_timeout_in_minutes

    @completion_timeout_in_minutes.setter
    def completion_timeout_in_minutes(self, completion_timeout_in_minutes):
        """Sets the completion_timeout_in_minutes of this PaymentAppCompletionConfigurationCreate.

            When the completion or the void is triggered we expect a feedback about the state of it. This timeout defines after how long we consider the void resp. completion as failed without receiving a final state update.

        :param completion_timeout_in_minutes: The completion_timeout_in_minutes of this PaymentAppCompletionConfigurationCreate.
        :type: int
        """

        self._completion_timeout_in_minutes = completion_timeout_in_minutes
    
    @property
    def maximal_completion_delay_in_days(self):
        """Gets the maximal_completion_delay_in_days of this PaymentAppCompletionConfigurationCreate.

            The completion resp. the void can be triggered a while after the authorization of the transaction has been executed. This delay defines how many days after the authorization the void resp. completion must be triggered at the latest.

        :return: The maximal_completion_delay_in_days of this PaymentAppCompletionConfigurationCreate.
        :rtype: int
        """
        return self._maximal_completion_delay_in_days

    @maximal_completion_delay_in_days.setter
    def maximal_completion_delay_in_days(self, maximal_completion_delay_in_days):
        """Sets the maximal_completion_delay_in_days of this PaymentAppCompletionConfigurationCreate.

            The completion resp. the void can be triggered a while after the authorization of the transaction has been executed. This delay defines how many days after the authorization the void resp. completion must be triggered at the latest.

        :param maximal_completion_delay_in_days: The maximal_completion_delay_in_days of this PaymentAppCompletionConfigurationCreate.
        :type: int
        """

        self._maximal_completion_delay_in_days = maximal_completion_delay_in_days
    
    @property
    def multiple_completions_supported(self):
        """Gets the multiple_completions_supported of this PaymentAppCompletionConfigurationCreate.

            This flag indicates whether the connector supports multiple completions for a single transaction or not.

        :return: The multiple_completions_supported of this PaymentAppCompletionConfigurationCreate.
        :rtype: bool
        """
        return self._multiple_completions_supported

    @multiple_completions_supported.setter
    def multiple_completions_supported(self, multiple_completions_supported):
        """Sets the multiple_completions_supported of this PaymentAppCompletionConfigurationCreate.

            This flag indicates whether the connector supports multiple completions for a single transaction or not.

        :param multiple_completions_supported: The multiple_completions_supported of this PaymentAppCompletionConfigurationCreate.
        :type: bool
        """

        self._multiple_completions_supported = multiple_completions_supported
    
    @property
    def void_endpoint(self):
        """Gets the void_endpoint of this PaymentAppCompletionConfigurationCreate.

            The void endpoint is invoked to request the payment service provider to execute a void.

        :return: The void_endpoint of this PaymentAppCompletionConfigurationCreate.
        :rtype: str
        """
        return self._void_endpoint

    @void_endpoint.setter
    def void_endpoint(self, void_endpoint):
        """Sets the void_endpoint of this PaymentAppCompletionConfigurationCreate.

            The void endpoint is invoked to request the payment service provider to execute a void.

        :param void_endpoint: The void_endpoint of this PaymentAppCompletionConfigurationCreate.
        :type: str
        """

        self._void_endpoint = void_endpoint
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppCompletionConfigurationCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppCompletionConfigurationCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriptionVersionItem:

    swagger_types = {
    
        'price_including_tax': 'float',
        'price_strategy': 'ShopifySubscriptionVersionItemPriceStrategy',
        'product': 'int',
        'quantity': 'float',
        'tax_lines': 'list[ShopifyTaxLine]',
    }

    attribute_map = {
        'price_including_tax': 'priceIncludingTax','price_strategy': 'priceStrategy','product': 'product','quantity': 'quantity','tax_lines': 'taxLines',
    }

    
    _price_including_tax = None
    _price_strategy = None
    _product = None
    _quantity = None
    _tax_lines = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.price_including_tax = kwargs.get('price_including_tax', None)
        self.price_strategy = kwargs.get('price_strategy', None)
        self.product = kwargs.get('product', None)
        self.quantity = kwargs.get('quantity', None)
        self.tax_lines = kwargs.get('tax_lines', None)
        

    
    @property
    def price_including_tax(self):
        """Gets the price_including_tax of this ShopifySubscriptionVersionItem.

            

        :return: The price_including_tax of this ShopifySubscriptionVersionItem.
        :rtype: float
        """
        return self._price_including_tax

    @price_including_tax.setter
    def price_including_tax(self, price_including_tax):
        """Sets the price_including_tax of this ShopifySubscriptionVersionItem.

            

        :param price_including_tax: The price_including_tax of this ShopifySubscriptionVersionItem.
        :type: float
        """

        self._price_including_tax = price_including_tax
    
    @property
    def price_strategy(self):
        """Gets the price_strategy of this ShopifySubscriptionVersionItem.

            

        :return: The price_strategy of this ShopifySubscriptionVersionItem.
        :rtype: ShopifySubscriptionVersionItemPriceStrategy
        """
        return self._price_strategy

    @price_strategy.setter
    def price_strategy(self, price_strategy):
        """Sets the price_strategy of this ShopifySubscriptionVersionItem.

            

        :param price_strategy: The price_strategy of this ShopifySubscriptionVersionItem.
        :type: ShopifySubscriptionVersionItemPriceStrategy
        """

        self._price_strategy = price_strategy
    
    @property
    def product(self):
        """Gets the product of this ShopifySubscriptionVersionItem.

            

        :return: The product of this ShopifySubscriptionVersionItem.
        :rtype: int
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this ShopifySubscriptionVersionItem.

            

        :param product: The product of this ShopifySubscriptionVersionItem.
        :type: int
        """

        self._product = product
    
    @property
    def quantity(self):
        """Gets the quantity of this ShopifySubscriptionVersionItem.

            

        :return: The quantity of this ShopifySubscriptionVersionItem.
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ShopifySubscriptionVersionItem.

            

        :param quantity: The quantity of this ShopifySubscriptionVersionItem.
        :type: float
        """

        self._quantity = quantity
    
    @property
    def tax_lines(self):
        """Gets the tax_lines of this ShopifySubscriptionVersionItem.

            

        :return: The tax_lines of this ShopifySubscriptionVersionItem.
        :rtype: list[ShopifyTaxLine]
        """
        return self._tax_lines

    @tax_lines.setter
    def tax_lines(self, tax_lines):
        """Sets the tax_lines of this ShopifySubscriptionVersionItem.

            

        :param tax_lines: The tax_lines of this ShopifySubscriptionVersionItem.
        :type: list[ShopifyTaxLine]
        """

        self._tax_lines = tax_lines
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionVersionItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionVersionItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractTokenUpdate:

    swagger_types = {
    
        'customer_email_address': 'str',
        'customer_id': 'str',
        'enabled_for_one_click_payment': 'bool',
        'language': 'str',
        'time_zone': 'str',
        'token_reference': 'str',
    }

    attribute_map = {
        'customer_email_address': 'customerEmailAddress','customer_id': 'customerId','enabled_for_one_click_payment': 'enabledForOneClickPayment','language': 'language','time_zone': 'timeZone','token_reference': 'tokenReference',
    }

    
    _customer_email_address = None
    _customer_id = None
    _enabled_for_one_click_payment = None
    _language = None
    _time_zone = None
    _token_reference = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.customer_email_address = kwargs.get('customer_email_address', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.enabled_for_one_click_payment = kwargs.get('enabled_for_one_click_payment', None)
        self.language = kwargs.get('language', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.token_reference = kwargs.get('token_reference', None)
        

    
    @property
    def customer_email_address(self):
        """Gets the customer_email_address of this AbstractTokenUpdate.

            The customer email address is the email address of the customer.

        :return: The customer_email_address of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._customer_email_address

    @customer_email_address.setter
    def customer_email_address(self, customer_email_address):
        """Sets the customer_email_address of this AbstractTokenUpdate.

            The customer email address is the email address of the customer.

        :param customer_email_address: The customer_email_address of this AbstractTokenUpdate.
        :type: str
        """
        if customer_email_address is not None and len(customer_email_address) > 150:
            raise ValueError("Invalid value for `customer_email_address`, length must be less than or equal to `150`")

        self._customer_email_address = customer_email_address
    
    @property
    def customer_id(self):
        """Gets the customer_id of this AbstractTokenUpdate.

            The customer ID identifies the customer in the merchant system. In case the customer ID has been provided it has to correspond with the customer ID provided on the transaction. The customer ID will not be changed automatically. The merchant system has to provide it.

        :return: The customer_id of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this AbstractTokenUpdate.

            The customer ID identifies the customer in the merchant system. In case the customer ID has been provided it has to correspond with the customer ID provided on the transaction. The customer ID will not be changed automatically. The merchant system has to provide it.

        :param customer_id: The customer_id of this AbstractTokenUpdate.
        :type: str
        """

        self._customer_id = customer_id
    
    @property
    def enabled_for_one_click_payment(self):
        """Gets the enabled_for_one_click_payment of this AbstractTokenUpdate.

            When a token is enabled for one-click payments the buyer will be able to select the token within the iFrame or on the payment page to pay with the token. The usage of the token will reduce the number of steps the buyer has to go through. The buyer is linked via the customer ID on the transaction with the token. Means the token will be visible for buyers with the same customer ID. Additionally the payment method has to be configured to allow the one-click payments.

        :return: The enabled_for_one_click_payment of this AbstractTokenUpdate.
        :rtype: bool
        """
        return self._enabled_for_one_click_payment

    @enabled_for_one_click_payment.setter
    def enabled_for_one_click_payment(self, enabled_for_one_click_payment):
        """Sets the enabled_for_one_click_payment of this AbstractTokenUpdate.

            When a token is enabled for one-click payments the buyer will be able to select the token within the iFrame or on the payment page to pay with the token. The usage of the token will reduce the number of steps the buyer has to go through. The buyer is linked via the customer ID on the transaction with the token. Means the token will be visible for buyers with the same customer ID. Additionally the payment method has to be configured to allow the one-click payments.

        :param enabled_for_one_click_payment: The enabled_for_one_click_payment of this AbstractTokenUpdate.
        :type: bool
        """

        self._enabled_for_one_click_payment = enabled_for_one_click_payment
    
    @property
    def language(self):
        """Gets the language of this AbstractTokenUpdate.

            The language that is linked to the object.

        :return: The language of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractTokenUpdate.

            The language that is linked to the object.

        :param language: The language of this AbstractTokenUpdate.
        :type: str
        """

        self._language = language
    
    @property
    def time_zone(self):
        """Gets the time_zone of this AbstractTokenUpdate.

            The time zone defines in which time zone the customer is located in. The time zone may affects how dates are formatted when interacting with the customer.

        :return: The time_zone of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AbstractTokenUpdate.

            The time zone defines in which time zone the customer is located in. The time zone may affects how dates are formatted when interacting with the customer.

        :param time_zone: The time_zone of this AbstractTokenUpdate.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def token_reference(self):
        """Gets the token_reference of this AbstractTokenUpdate.

            Use something that it is easy to identify and may help you find the token (e.g. customer id, email address).

        :return: The token_reference of this AbstractTokenUpdate.
        :rtype: str
        """
        return self._token_reference

    @token_reference.setter
    def token_reference(self, token_reference):
        """Sets the token_reference of this AbstractTokenUpdate.

            Use something that it is easy to identify and may help you find the token (e.g. customer id, email address).

        :param token_reference: The token_reference of this AbstractTokenUpdate.
        :type: str
        """
        if token_reference is not None and len(token_reference) > 100:
            raise ValueError("Invalid value for `token_reference`, length must be less than or equal to `100`")

        self._token_reference = token_reference
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractTokenUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractTokenUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
